from distutils.core import setup

setup(
    name='nesterSpaceHolder',
    version='1.5.0',
    py_modules=['nesterSpaceHolder'],
    author='Stuart',
    author_email='beefstew2002@outlook.com',
    url='http://westada.tech/b4/stuarte/',
    description='A simple printer of nested lists',
    )
